==> heptapod-rails-0.16.1.tar.gz: heptapod-rails-0.16.1/lib/gitlab/mercurial/wiki.rb <==
# frozen_string_literal: true

module Gitlab
  module Mercurial
    class Wiki < Gitlab::Git::Wiki

      # in super class, initialize() is from a repository,
      # it will work right away with one from Gitlab::Mercurial

      def hg_gitlab_branch
        'branch/default'
      end

      # intended for writers that don't go through this class
      # e.g, Repository model `multi_action`,
      # called from Wikis::CreateAttachmentServices.
      #
      # Since we can't change the `default_branch` method,
      # leaving it as 'master' (all the reads depend on it), we
      # must provide means to correct on the fly.
      def self.fixup_default_branch(branch)
        branch == 'master' ? 'branch/default' : branch
      end

      User = Struct.new(:id, :username, :name, :email) do
        def self.from(commit_details)
          self.new(commit_details.user_id,
                   commit_details.username,
                   commit_details.name,
                   commit_details.email)
        end
      end

      def write_page(name, format, content, commit_details)
        repository.multi_action(
          User.from(commit_details),
          branch_name: hg_gitlab_branch,
          start_branch_name: hg_gitlab_branch,
          message: commit_details.message,
          actions: [{action: :create,
                     content: content,
                     file_path: gollum_page_path(name, format)
                    }]
        )
        # TODO catch Mercurial::Repository::FileExists and raise appropriately
      end

      def gollum_page_path(name, format)
        # TODO make sure of what is the expected path
        g = self.class::GollumSlug
        # this undoing part of what g::generate does, but it's better than
        # duplicating it.
        # we don't care about the FS separator not being '/' here: that's the
        # job of the inner layers. In the case of upstream GitLab, this
        # will end up as a Gitaly request. If Gitaly is supported on Windows
        # then there's no reason to believe the Rails app should be on
        # Windows as well
        [g::generate(name, format), g::format_to_ext(format.to_sym)].join('.')
      end

      def update_page(page_path, name, format, content, commit_details)
        # In the pure Gollum way of doing, the first argument would be
        # an instance of Page, and GitLab would perform this look up:
        #
        #   page = gollum_page_by_path(page_path)
        #
        # with
        #
        #   def gollum_page_by_path(page_path)
        #     page_name = Gollum::Page.canonicalize_filename(page_path)
        #     page_dir = File.split(page_path).first
        #     gollum_wiki.paged(page_name, page_dir) || (raise PageNotFound, page_path)
        #   end
        new_file_path = gollum_page_path(name, format)
        actions = [{action: :update,
                    content: content,
                    file_path: page_path}
                  ]
        if new_file_path != page_path
          actions << {action: :move,
                      previous_path: page_path,
                      file_path: new_file_path}
        end
        repository.multi_action(
          User.from(commit_details),
          branch_name: hg_gitlab_branch,
          start_branch_name: hg_gitlab_branch,
          message: commit_details.message,
          actions: actions
        )
        Gitaly::WikiWritePageResponse.new  # TODO produce duplicate error if needed (because of rename)
      end

    end
  end
end

==> heptapod-rails-0.26.0.tar.gz: heptapod-rails-0.26.0/lib/gitlab/mercurial/wiki.rb <==
# frozen_string_literal: true

module Gitlab
  module Mercurial
    class Wiki < Gitlab::Git::Wiki
      # in super class, initialize() is from a repository,
      # it will work right away with one from Gitlab::Mercurial

      def hg_gitlab_branch
        'branch/default'
      end

      # intended for writers that don't go through this class
      # e.g, Repository model `multi_action`,
      # called from Wikis::CreateAttachmentServices.
      #
      # Since we can't change the `default_branch` method,
      # leaving it as 'master' (all the reads depend on it), we
      # must provide means to correct on the fly.
      def self.fixup_default_branch(branch)
        branch == 'master' ? 'branch/default' : branch
      end

      User = Struct.new(:id, :username, :name, :email) do
        def self.from(commit_details)
          self.new(commit_details.user_id,
                   commit_details.username,
                   commit_details.name,
                   commit_details.email)
        end
      end

      # rubocop: disable CodeReuse/ActiveRecord
      def write_page(name, format, content, commit_details)
        repository.multi_action(
          User.from(commit_details),
          branch_name: hg_gitlab_branch,
          start_branch_name: hg_gitlab_branch,
          message: commit_details.message,
          actions: [{ action: :create,
                     content: content,
                     file_path: gollum_page_path(name, format) }]
        )
        # TODO catch Mercurial::Repository::FileExists and raise appropriately
      end
      # rubocop: enable CodeReuse/ActiveRecord

      def gollum_page_path(name, format)
        # TODO make sure of what is the expected path
        g = self.class::GollumSlug
        # this undoing part of what g::generate does, but it's better than
        # duplicating it.
        # we don't care about the FS separator not being '/' here: that's the
        # job of the inner layers. In the case of upstream GitLab, this
        # will end up as a Gitaly request. If Gitaly is supported on Windows
        # then there's no reason to believe the Rails app should be on
        # Windows as well
        [g.generate(name, format), g.format_to_ext(format.to_sym)].join('.')
      end

      # rubocop: disable CodeReuse/ActiveRecord
      def update_page(page_path, name, format, content, commit_details)
        # In the pure Gollum way of doing, the first argument would be
        # an instance of Page, and GitLab would perform this look up:
        #
        #   page = gollum_page_by_path(page_path)
        #
        # with
        #
        #   def gollum_page_by_path(page_path)
        #     page_name = Gollum::Page.canonicalize_filename(page_path)
        #     page_dir = File.split(page_path).first
        #     gollum_wiki.paged(page_name, page_dir) || (raise PageNotFound, page_path)
        #   end
        new_file_path = gollum_page_path(name, format)
        actions = [{ action: :update,
                    content: content,
                    file_path: page_path }]

        if new_file_path != page_path
          actions << { action: :move,
                      previous_path: page_path,
                      file_path: new_file_path }
        end

        repository.multi_action(
          User.from(commit_details),
          branch_name: hg_gitlab_branch,
          start_branch_name: hg_gitlab_branch,
          message: commit_details.message,
          actions: actions
        )
        Gitaly::WikiWritePageResponse.new # TODO produce duplicate error if needed (because of rename)
      end
      # rubocop: enable CodeReuse/ActiveRecord
    end
  end
end
